@@ -2,20 +2,12 @@
 #'
 #' Identify parental lines based on GEBV-GD strategy and simulate their offsprings.
 #'
-#' @param t1 vector. The phenotype of trait1. The missing value must be coded as NA.
-#' The length of all triat must be the same.
-#' @param t2 vector. The phenotype of trait2. The missing value must be coded as NA.
-#' The length of all triat must be the same.
-#' @param t3 vector. The phenotype of trait3. The missing value must be coded as NA.
-#' The length of all triat must be the same.
-#' @param t4 vector. The phenotype of trait4. The missing value must be coded as NA.
-#' The length of all triat must be the same.
-#' @param t5 vector. The phenotype of trait5. The missing value must be coded as NA.
-#' The length of all triat must be the same.
+#' @param fitted.t matrix. An n*t matrix denotes the fitted values of each traits
+#' of the training population. The missing value must have been already imputed.
 #' @param geno.t matrix. An n*p matrix denotes the marker score matrix of the
 #' training population. The markers must be coded as 1, 0, or -1 for alleles
 #' AA, Aa, or aa. The missing value must have been already imputed.
-#' @param marker matrix. An p*2 matrix whose first column indicates the chromosome
+#' @param marker matrix. A p*2 matrix whose first column indicates the chromosome
 #' number to which a marker belongs; and second column indicates the position of
 #' the marker in centi-Morgan (cM).
 #' @param geno.c matrix. An nc*p matrix denotes the marker score matrix of the
@@ -72,9 +64,8 @@
 #' @note
 #' The function output.best and output.gain can be used to summarize the result.
 #'
-#' Due to restrictions on the use of the funtion 'mmer', if an unknown error occurs
-#' during use, please try to input the phenotype data as the format shown in the
-#' example.
+#' The fitted value data in the input data can be obtained by the function
+#' GBLUP.fit and mmer, that can be seen in the Examples shown below.
 #'
 #' @export
 #'
@@ -96,32 +87,60 @@
 #' @examples
 #' # generate simulated data
 #' set.seed(2000)
-#' t1 = rnorm(10,30,10)
-#' t2 = rnorm(10,10,5)
-#' t3 = NULL
-#' t4 = NULL
-#' t5 = NULL
+#' t1 <- rnorm(10,30,10)
+#' t2 <- rnorm(10,10,5)
+#' t3 <- NULL
+#' t4 <- NULL
+#' t5 <- NULL
 #' geno.test <- matrix(sample(c(1, -1), 200, replace = TRUE), 10, 20)
 #' marker.test <- cbind(rep(1:2, each=10), rep(seq(0, 90, 10), 2))
+#' fit <- GBLUP.fit(t1, t2, t3, t4, t5, geno = geno.test)
+#'
 #' geno.candidate <- matrix(sample(c(1,-1), 300, replace = TRUE), 15, 20)
 #'
 #' # run and output
-#' result <- simu.GEBVGD(t1, t2, t3, t4, t5, geno.test, marker.test, geno.candidate,
+#' result <- simu.GEBVGD(fit, geno.test, marker.test, geno.candidate,
 #' nprog = 5, nsele = 10, ngen = 5, nrep = 5, cri = 250)
 #' result$suggested.subset
-simu.GEBVGD <- function(t1, t2, t3, t4, t5, geno.t, marker, geno.c = NULL, npl = NULL, better.c = FALSE,
+#'
+#'
+#'
+#' # other method: use mmer to obtain the fitted value
+#' \dontrun{
+#' set.seed(2000)
+#' t1 <- rnorm(10,30,10)
+#' t2 <- rnorm(10,10,5)
+#' phe <- cbind(t1, t2)
+#' nt <- ncol(phe)
+#' geno.test <- matrix(sample(c(1, -1), 200, replace = TRUE), 10, 20)
+#' marker.test <- cbind(rep(1:2, each=10), rep(seq(0, 90, 10), 2))
+#' rownames(geno.test) <- 1:nrow(geno.test)
+#' id <- rownames(geno.test)
+#' K0 <- geno.test%*%t(geno.test)/ncol(geno.test)
+#' diag(K0) <- 1
+#'
+#' dat <- data.frame(id, phe)
+#' fit0 <- sommer::mmer(cbind(t1, t2)~1,
+#'       random = ~sommer::vs(id, Gu = K0, Gtc = sommer::unsm(nt)),
+#'       rcov = ~sommer::vs(units, Gtc = sommer::unsm(nt)),
+#'       data = dat,
+#'       tolparinv = 0.01)
+#'
+#' u0 <- fit0$U$`u:id`
+#' fit <- matrix(unlist(u0), ncol = nt)
+#' colnames(fit) <- names(u0)
+#'
+#' fit <- fit+matrix(fit0$fitted[1,], nrow(fit), nt, byrow = TRUE)
+#' fit <- fit[order(as.numeric(names((u0[[1]])))),]
+#' }
+simu.GEBVGD <- function(fitted.t, geno.t, marker, geno.c = NULL, npl = NULL, better.c = FALSE,
                         npl.best = NULL, weight = NULL, direction = NULL, nprog = 50, nsele = NULL, ngen = 10,
                         nrep = 30, cri = 10000, console = TRUE){
 
-  phetest <- c(length(t1), length(t2), length(t3), length(t4), length(t5))
-  if(length(table(phetest[phetest != 0])) != 1){
-    stop("Phenotype data error, please input number vectors with the same length.", call. = FALSE)
-  }
-
-  phe.t <- cbind(t1, t2, t3, t4, t5)
+  phe.t <- fitted.t
   datatry <- try(phe.t*phe.t, silent=TRUE)
-  if(class(datatry)[1] == "try-error"){
-    stop("Phenotype data error, please input number vectors with the same length.", call. = FALSE)
+  if(class(datatry)[1] == "try-error" | NA %in% phe.t){
+    stop("Phenotype data error, please cheak your phenotype data and impute the missing value.", call. = FALSE)
   }
 
   nt <- ncol(phe.t)
@@ -163,13 +182,12 @@ simu.GEBVGD <- function(t1, t2, t3, t4, t5, geno.t, marker, geno.c = NULL, npl =
     stop("Marker data error, please cheak your marker data.", call. = FALSE)
   }
 
-  fit0 <- GBLUP.fit(t1, t2, t3, t4, t5, geno = geno.t)
   phe1 <- phe.sd(phe.t)
   mu0 <- phe1[[2]]
   sd0 <- phe1[[3]]
-  fit <- phe.sd(fit0)[[1]]
+  fit <- phe1[[1]]
 
-  row.names(fit) <- 1:nrow(fit0)
+  row.names(fit) <- 1:nrow(fitted.t)
   K0 <- geno.t%*%t(geno.t)/ncol(geno.t)
   diag(K0) <- 1
   d0 <- det(K0)
